@@ -8,4 +8,7 @@ mod error;
 mod rest;
 
 pub use error::KeycloakError;
-pub use rest::{KeycloakAdmin, KeycloakAdminToken, KeycloakTokenSupplier};
+pub use rest::{
+    KeycloakAdmin, KeycloakAdminToken, KeycloakServiceAccountAdminTokenRetriever,
+    KeycloakTokenSupplier,
+};
\ No newline at end of file
